| Title: | Set Axis Break for 'ggplot2' |
| Version: | 0.2.2 |
| Description: | An implementation of scale functions for setting axis breaks of a 'gg' plot (S Xu (2021) <doi:10.3389/fgene.2021.774846>). |
| Imports: | ggfun (≥ 0.1.1), grid, ggplot2 (≥ 4.0.0), ggplotify (≥ 0.0.7), aplot (≥ 0.1.5), gtable, patchwork, rlang, stats, yulab.utils (≥ 0.1.9) |
| Suggests: | ggimage, ggrepel, ggsignif, knitr, pillar, prettydoc, rmarkdown, testthat |
| VignetteBuilder: | knitr |
| License: | Artistic-2.0 |
| Encoding: | UTF-8 |
| URL: | https://github.com/YuLab-SMU/ggbreak |
| BugReports: | https://github.com/YuLab-SMU/ggbreak/issues |
| Config/roxygen2/version: | 8.1.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-09-22 06:43:34 UTC; wang |
| Author: | Guangchuang Yu |
| Maintainer: | Guangchuang Yu <guangchuangyu@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-22 07:20:08 UTC |
ggbreak: Set Axis Break for 'ggplot2'
Description
An implementation of scale functions for setting axis breaks of a 'gg' plot (S Xu (2021) doi:10.3389/fgene.2021.774846).
Author(s)
Maintainer: Guangchuang Yu guangchuangyu@gmail.com (ORCID) [copyright holder]
Authors:
Guangchuang Yu guangchuangyu@gmail.com (ORCID) [copyright holder]
Shuangbin Xu xshuangbin@163.com (ORCID)
See Also
Useful links:
scale-wrap
Description
This scale function wraps a 'gg' plot over multiple rows to make plots with long x axes easier to read.
Usage
scale_wrap(n)
Arguments
n |
the number of subplot pieces. |
Details
A plot can be broken on both axes (scale_x_break() with scale_y_break()), but a wrapping, breaking or cutting scale cannot be combined with a different one of them.
Value
gg object
Examples
library(ggplot2)
library(ggbreak)
p <- ggplot(economics, aes(x=date, y = unemploy, colour = uempmed)) +
geom_line()
p + scale_wrap(n=4)
scale_x_break
Description
Set an axis break point for a 'gg' plot
Usage
scale_x_break(
breaks,
scales = "fixed",
ticklabels = NULL,
expand = TRUE,
space = 0.1,
symbol = NULL,
bridge = FALSE
)
scale_y_break(
breaks,
scales = "fixed",
ticklabels = NULL,
expand = TRUE,
space = 0.1,
symbol = NULL,
bridge = FALSE
)
Arguments
breaks |
break point. For a discrete axis these are the names of two
levels, and the levels lying strictly between them are dropped, so two
adjacent levels only insert a gap. For a date or datetime axis they may be
given as |
scales |
relative width or height of subplots, default is "fixed". If scale is 'free', all subplots have equal width or height. It also can be any number to set relative width or height compare to first subplot. |
ticklabels |
the axis labels to subplot, default is NULL. |
expand |
default is TRUE, logical or a vector of range expansion constants
used to add some padding around the data to ensure that they
are placed some distance away from the axes. Use the convenience
function |
space |
the blank space among the subplots after break, default is 0.1 (cm). |
symbol |
the break symbol, default is NULL, could be 'slash'. |
bridge |
whether to draw the piece of a line that the break hides, so
that a line crossing the break reads as one line instead of two, default is
FALSE. Only the lines of |
Details
This scale function set an axis break point for a 'gg' plot. Either 'x' and 'y' axes are supported. The result is still a 'gg' object and user can progressively add layers to it. A plot can be broken on both axes (scale_x_break() with scale_y_break()), but a wrapping, breaking or cutting scale cannot be combined with a different one of them.
Value
gg object
Author(s)
Guangchuang Yu
Examples
require(ggplot2 )
set.seed(2019-01-19)
d <- data.frame(
x = 1:20,
y = c(rnorm(5) + 4, rnorm(5) + 20, rnorm(5) + 5, rnorm(5) + 22)
)
p <- ggplot(d, aes(x, y)) + geom_col()
x <- p+scale_y_break(c(7, 17 ) )
print(x)
scale_x_cut
Description
scale_x_cut
scale_y_cut
Usage
scale_x_cut(breaks, which = NULL, scales = NULL, expand = FALSE, space = 0.1)
scale_y_cut(breaks, which = NULL, scales = NULL, expand = FALSE, space = 0.1)
Arguments
breaks |
a numeric or numeric vector, the points to be divided |
which |
integer, the position of subplots to scales, started from left to right or top to bottom. |
scales |
numeric, relative width or height of subplots. |
expand |
default is FALSE, logical a vector of range expansion constants
used to add some padding around the data to ensure that they
are placed some distance away from the axes. Use the convenience
function |
space |
the blank space among the subplots after cut, default is 0.1 (cm). |
Details
A plot can be broken on both axes (scale_x_break() with scale_y_break()), but a wrapping, breaking or cutting scale cannot be combined with a different one of them.
Value
gg object
Examples
library(ggplot2)
library(ggbreak)
set.seed(2019-01-19)
d <- data.frame(
x = 1:20,
y = c(rnorm(5) + 4, rnorm(5) + 20, rnorm(5) + 5, rnorm(5) + 22)
)
p <- ggplot(d, aes(x, y)) + geom_col()
p + scale_y_cut(breaks=c(7, 18), which=c(1, 3), scales=c(3, 0.5))